@@ -23,9 +23,7 @@
 
 #define HAVE_NR_PROCESS_VM_READV 1
 
-#ifndef HAVE_LIBCOMPRESSION
-/* #undef HAVE_LIBCOMPRESSION */
-#endif
+#define HAVE_LIBCOMPRESSION 0
 
 #define LLDB_ENABLE_POSIX 1
 
